@@ -14,6 +14,14 @@
     unused_qualifications,
     warnings
 )]
+#![cfg_attr(not(feature = "std"), no_std)]
+
+#[cfg(feature = "std")]
+extern crate core;
+
+#[cfg(feature = "alloc")]
+extern crate alloc;
+
 mod error;
 mod local_info;
 mod secure_channel;
@@ -31,6 +39,7 @@ pub use traits::*;
 #[cfg(test)]
 mod tests {
     use crate::SecureChannel;
+    use ockam_core::compat::string::{String, ToString};
     use ockam_core::Route;
     use ockam_key_exchange_core::NewKeyExchanger;
     use ockam_key_exchange_xx::XXNewKeyExchanger;
